@@ -65,6 +65,9 @@ GtkUIManager     *ui = NULL;
 GtkWidget        *status_bar;
 GtkWidget        *balance_value_label;
 
+GtkAction *fullscreen_action;
+GtkAction *leave_fullscreen_action;
+
 guint32          seed;
 
 guint            x_spacing = 5;
@@ -78,6 +81,7 @@ gfloat wager_value = 5.0;
 gfloat balance_value = 0.0;
 gboolean quick_deals = FALSE;
 gboolean show_probabilities = FALSE;
+gboolean never_insurance = FALSE;
 gboolean show_toolbar = TRUE;
 gchar *game_variation = NULL;
 
@@ -158,6 +162,36 @@ bj_adjust_wager (gdouble offset)
         bj_set_wager (wager);
 }
 
+static void 
+set_fullscreen_actions (gboolean is_fullscreen)
+{
+        gtk_action_set_sensitive (leave_fullscreen_action, is_fullscreen);
+        gtk_action_set_visible (leave_fullscreen_action, is_fullscreen);
+
+        gtk_action_set_sensitive (fullscreen_action, !is_fullscreen);
+        gtk_action_set_visible (fullscreen_action, !is_fullscreen);
+}
+
+static void 
+fullscreen_cb (GtkAction *action)
+{
+	if (action == fullscreen_action) {
+		gtk_window_fullscreen (GTK_WINDOW (toplevel_window));
+	} else {
+		gtk_window_unfullscreen (GTK_WINDOW (toplevel_window));
+	}
+}
+
+/* Just in case something else takes us to/from fullscreen. */
+static void 
+window_state_cb (GtkWidget *widget, GdkEventWindowState *event)
+{
+	if (event->changed_mask & GDK_WINDOW_STATE_FULLSCREEN)
+        	set_fullscreen_actions (event->new_window_state &
+					GDK_WINDOW_STATE_FULLSCREEN);
+}
+
+
 static void
 bj_create_board (void)
 {
@@ -265,8 +299,12 @@ create_main_window (void)
                 "      <menuitem name='Quit' action='quit-game' />"
                 "      <placeholder name='GameMenuAdditions' />"
                 "    </menu>"
-                "    <menu name='SettingsMenu' action='settings-menu'>"
+		"    <menu name='ViewMenu' action='view-menu'>"
                 "      <menuitem name='Toolbar' action='show-toolbar'/>"
+		"      <menuitem action='Fullscreen'/>"
+		"      <menuitem action='LeaveFullscreen'/>"
+		"    </menu>"
+                "    <menu name='SettingsMenu' action='settings-menu'>"
                 "      <menuitem name='Preferences' action='show-preferences'/>"
                 "    </menu>"
                 "    <menu name='ControlMenu' action='control-menu'>"
@@ -295,11 +333,14 @@ create_main_window (void)
 
         static GtkActionEntry entries [] = {
                 { "game-menu", NULL, N_("_Game") },
-                { "new-game", GAMES_STOCK_NEW_GAME, NULL, NULL, NULL, G_CALLBACK (on_game_new_activate) },
-                { "restart-game", GAMES_STOCK_RESTART_GAME, NULL, NULL, NULL, G_CALLBACK (on_game_restart_activate) },
-                { "show-hint", GAMES_STOCK_HINT, NULL, NULL, NULL, G_CALLBACK (on_game_hint_activate) },
+		{ "view-menu", NULL, N_("_View") },
+                { "new-game", GAMES_STOCK_NEW_GAME, NULL, NULL, N_("Start a new game"), G_CALLBACK (on_game_new_activate) },
+                { "restart-game", GAMES_STOCK_RESTART_GAME, NULL, NULL, N_("Restart the current game"), G_CALLBACK (on_game_restart_activate) },
+                { "show-hint", GAMES_STOCK_HINT, NULL, NULL, N_("Show a hint"), G_CALLBACK (on_game_hint_activate) },
                 { "quit-game", GTK_STOCK_QUIT, NULL, NULL, NULL, G_CALLBACK (on_game_quit_activate) },
                 { "settings-menu", NULL, N_("_Settings") },
+		{ "Fullscreen", GAMES_STOCK_FULLSCREEN, NULL, NULL, NULL, G_CALLBACK (fullscreen_cb) },
+		{ "LeaveFullscreen", GAMES_STOCK_LEAVE_FULLSCREEN, NULL, NULL, NULL, G_CALLBACK (fullscreen_cb) },
                 { "show-preferences", GTK_STOCK_PREFERENCES, NULL, NULL, NULL, G_CALLBACK (on_preferences_activate) },
                 { "control-menu", NULL, N_("_Control") },
                 { "hand-deal", NULL, N_("D_eal"), NULL, N_("Deal a new hand"), G_CALLBACK (on_control_deal_activate) },
@@ -389,12 +430,21 @@ create_main_window (void)
 
         gtk_window_set_default_size (GTK_WINDOW (toplevel_window), width, height);
 
+	fullscreen_action = gtk_action_group_get_action (actions, "Fullscreen");
+	leave_fullscreen_action = gtk_action_group_get_action (actions,
+							       "LeaveFullscreen");
+
         bj_update_control_menu ();
 
+	set_fullscreen_actions (FALSE);
+
         g_signal_connect (toplevel_window, "delete_event", 
                           G_CALLBACK (bj_quit_app), NULL);
         g_signal_connect (toplevel_window, "configure_event",
                           G_CALLBACK (bj_event_configure), NULL);
+	g_signal_connect (G_OBJECT (toplevel_window), "window_state_event",
+			  G_CALLBACK (window_state_cb), NULL);
+
 }
 
 static void
@@ -427,6 +477,8 @@ main_prog (int argc, char *argv[])
         gtk_widget_pop_colormap ();
 
         gtk_main ();
+
+		gnome_accelerators_sync();
 }
 
 GConfClient *
@@ -475,6 +527,14 @@ bj_gconf_quick_deal_cb (GConfClient *client, guint cnxn_id,
         bj_draw_refresh_screen ();
 }
 
+static void
+bj_gconf_never_insurance_cb (GConfClient *client, guint cnxn_id, 
+                             GConfEntry *entry, gpointer user_data)
+{
+        never_insurance = gconf_client_get_bool (client, GCONF_KEY_NEVER_INSURANCE, NULL);
+        bj_draw_refresh_screen ();
+}
+
 static void
 bj_gconf_show_toolbar_cb (GConfClient *client, guint cnxn_id, 
                           GConfEntry *entry, gpointer user_data)
@@ -546,6 +606,19 @@ bj_set_quick_deal (gboolean value)
                                value, NULL);
 }
 
+gboolean
+bj_get_never_insurance ()
+{
+        return never_insurance;
+}
+void
+bj_set_never_insurance (gboolean value)
+{
+        gconf_client_set_bool (bj_gconf_client (), 
+                               GCONF_KEY_NEVER_INSURANCE,
+                               value, NULL);
+}
+
 gchar *
 bj_get_game_variation ()
 {
@@ -616,6 +689,9 @@ bj_gconf_init (GConfClient *client)
         quick_deals = gconf_client_get_bool (client, 
                                              GCONF_KEY_QUICK_DEAL,
                                              NULL);
+        never_insurance = gconf_client_get_bool (client, 
+                                                 GCONF_KEY_NEVER_INSURANCE,
+                                                 NULL);
         show_toolbar = gconf_client_get_bool (client, 
                                               GCONF_KEY_SHOW_TOOLBAR,
                                               NULL);
@@ -636,6 +712,10 @@ bj_gconf_init (GConfClient *client)
                                  GCONF_KEY_QUICK_DEAL,
                                  bj_gconf_quick_deal_cb,
                                  NULL, NULL, NULL);
+        gconf_client_notify_add (client,
+                                 GCONF_KEY_NEVER_INSURANCE,
+                                 bj_gconf_never_insurance_cb,
+                                 NULL, NULL, NULL);
         gconf_client_notify_add (client,
                                  GCONF_KEY_SHOW_TOOLBAR,
                                  bj_gconf_show_toolbar_cb,
@@ -673,15 +753,16 @@ main (int argc, char *argv [])
                               GCONF_CLIENT_PRELOAD_NONE, NULL);
 
 #ifdef HAVE_GNOME
-        gnome_program_init ("Blackjack", VERSION,
-                            LIBGNOMEUI_MODULE,
-                            argc, argv,
-                            GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+        GnomeProgram *program;
+        program = gnome_program_init ("Blackjack", VERSION,
+                                      LIBGNOMEUI_MODULE,
+                                      argc, argv,
+                                      GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
 #endif
 
         gtk_widget_push_colormap (gdk_rgb_get_colormap ());
 
-        gtk_window_set_default_icon_from_file (PIXMAPDIR"/gnome-blackjack.png", NULL);
+        gtk_window_set_default_icon_name ("gnome-blackjack");
 
         bj_gconf_init (bj_gconf_client ());
 
@@ -691,5 +772,9 @@ main (int argc, char *argv [])
 
         g_free (variation);
 
+#ifdef HAVE_GNOME
+        g_object_unref (program);
+#endif
+
         return 0;
 }
