@@ -2,7 +2,7 @@
  * @file   ggz.h
  * @author Brent M. Hendricks
  * @date   Fri Nov  2 23:32:17 2001
- * $Id: ggz.h,v 1.5 2006/12/10 19:28:12 andreasr Exp $
+ * $Id: ggz.h 5767 2006-12-22 14:55:25Z andreasr $
  * 
  * Header file for ggz components lib
  *
@@ -53,6 +53,8 @@ extern "C" {
 #endif
 
 #if defined __GNUC__ && (__GNUC__ >= 3)
+#  define _GGZFUNCTION_ "" 
+#elif defined(__sun)
 #  define _GGZFUNCTION_ ""
 #else
 #  ifndef __cplusplus
