@@ -172,7 +172,7 @@ class GtkViewArea(gtk.DrawingArea):
             try:
                 if self.view.feedback is not None:
                     self.view.feedback.renderGL()
-            except OpenGL.GLerror, e:
+            except OpenGL.GL.GLerror, e:
                 print 'Rendering Error: ' + str(e)
                 traceback.print_exc(file = sys.stdout)
 
