@@ -47,22 +47,6 @@ init_sound (void)
 }
 
 
-/**
- * cleanup_sound
- *
- * Description:
- * Cleans up the sound resources 
- *
- * Returns:
- * TRUE on success FALSE otherwise
- **/
-gboolean
-cleanup_sound (void)
-{
-  return TRUE;
-}
-
-
 /**
  * play_sound
  * @sno: sound number
@@ -99,9 +83,9 @@ play_sound (gint sno)
     case SOUND_BAD:
 #if 0
       if (gnome_sound_connection >= 0) {
-        gnome_triggers_do ("", "program", GAME_NAME, "bad-move", NULL);
+	gnome_triggers_do ("", "program", GAME_NAME, "bad-move", NULL);
       } else {
-        gdk_beep ();
+	gdk_beep ();
       }
 #endif
       gdk_beep ();
@@ -112,7 +96,7 @@ play_sound (gint sno)
     }
 
   }
-  
+
   return TRUE;
 }
 
