@@ -155,13 +155,14 @@ class UI (gconf_wrapper.GConfWrapper):
                      'bg_black':1,
                      'bg_custom_color':'',
                      'show_tracker':False,
+                     'width': 700,
+                     'height': 675
                      #'show_notes':0
                      }    
 
     @simple_debug
     def __init__ (self):
         self.w = gtk.Window()
-        self.w.set_default_size(700,675)
         self.timer = ActiveTimer(self.w)
         self.won = False
         gconf_wrapper.GConfWrapper.__init__(self,
@@ -175,7 +176,8 @@ class UI (gconf_wrapper.GConfWrapper):
         gnome.program_init('gnome-sudoku',VERSION,
                            properties={gnome.PARAM_APP_DATADIR:APP_DATA_DIR}
                            )
-	self.w.set_title(APPNAME);
+        self.w.set_title(APPNAME);
+        self.w.connect('configure-event',self.resize_cb)
         self.w.connect('delete-event',self.quit_cb)
         self.vb = gtk.VBox()
         self.uimanager = gtk.UIManager()
@@ -443,16 +445,16 @@ class UI (gconf_wrapper.GConfWrapper):
         #                                )
         #sublabel = _("You completed the puzzle in %s")%time_string
         #sublabel += "\n"
-        #sublabel += ngettext("You got %s hint","You got %s hints",self.gsd.hints)%self.gsd.hints
+        #sublabel += ngettext("You got %(n)s hint","You got %(n)s hints",self.gsd.hints)%{'n':self.gsd.hints}
         #sublabel += "\n"
         #if self.gsd.impossible_hints:
-        #    sublabel += ngettext("You had %s impossibility pointed out.",
-        #                         "You had %s impossibilities pointed out.",
-        #                         self.gsd.impossible_hints)%self.gsd.impossible_hints
+        #    sublabel += ngettext("You had %(n)s impossibility pointed out.",
+        #                         "You had %(n)s impossibilities pointed out.",
+        #                         self.gsd.impossible_hints)%{'c':self.gsd.impossible_hints}
         #if self.gsd.auto_fills:
-        #    sublabel += ngettext("You used the auto-fill %s time",
-        #                         "You used the auto-fill %s times",
-        #                         self.gsd.auto_fills)%self.gsd.auto_fills
+        #    sublabel += ngettext("You used the auto-fill %(n)s time",
+        #                         "You used the auto-fill %(n)s times",
+        #                         self.gsd.auto_fills)%{'n':self.gsd.auto_fills}
         #dialog_extras.show_message("You win!",label="You win!",
         #                           icon=os.path.join(IMAGE_DIR,'winner2.png'),
         #                           sublabel=sublabel
@@ -496,6 +498,11 @@ class UI (gconf_wrapper.GConfWrapper):
         self.timer.reset_timer()
         self.timer.start_timing()
         self.won = False
+        
+    @simple_debug
+    def resize_cb (self, widget, event):
+        self.gconf['width'] = event.width
+        self.gconf['height'] = event.height
 
     @simple_debug
     def quit_cb (self, *args):
@@ -719,11 +726,11 @@ class UI (gconf_wrapper.GConfWrapper):
         #        time_string += " %s"%_('paused')
         #    tot_string += " - " + time_string
         #if self.gsd.hints and not self.gconf['always_show_hints']:
-        #    tot_string += " -  " +ngettext("%s hint","%s hints",
-        #                           self.gsd.hints)%self.gsd.hints
+        #    tot_string += " -  " +ngettext("%(n)s hint","%(n)s hints",
+        #                           self.gsd.hints)%{'n':self.gsd.hints}
         #if self.gsd.auto_fills:
-        #    tot_string += "  " +ngettext("%s auto-fill","%s auto-fills",
-        #                            self.gsd.auto_fills)%self.gsd.auto_fills
+        #    tot_string += "  " +ngettext("%(n)s auto-fill","%(n)s auto-fills",
+        #                            self.gsd.auto_fills)%{'n':self.gsd.auto_fills}
         if not hasattr(self,'sbid'):
             self.sbid = self.statusbar.get_context_id('game_info')
         self.statusbar.pop(self.sbid)
@@ -945,7 +952,7 @@ class TrackerBox (gtk.VBox):
     def tracker_delete_tracks (self, tracker_id):
         clearer=Undo.UndoableObject(
             lambda *args: self.main_ui.cleared.append(self.main_ui.gsd.delete_by_tracker(tracker_id)),
-            lambda *args: [self.main_ui.gsd.add(*entry) for entry in self.main_ui.cleared.pop()],
+            lambda *args: [self.main_ui.gsd.add_value(*entry) for entry in self.main_ui.cleared.pop()],
             self.main_ui.history)
         clearer.perform()
 
@@ -953,7 +960,7 @@ class TrackerBox (gtk.VBox):
     def tracker_keep_tracks (self, tracker_id):
         clearer=Undo.UndoableObject(
             lambda *args: self.main_ui.cleared.append(self.main_ui.gsd.delete_except_for_tracker(tracker_id)),
-            lambda *args: [self.main_ui.gsd.add(*entry) for entry in self.main_ui.cleared.pop()],
+            lambda *args: [self.main_ui.gsd.add_value(*entry) for entry in self.main_ui.cleared.pop()],
             self.main_ui.history)
         clearer.perform()
 
