@@ -1,6 +1,7 @@
 import gtk, cairo, pango, gobject
 import colors
 import math
+import random
 from simple_debug import simple_debug
 from gettext import gettext as _
 import sudoku
@@ -232,6 +233,9 @@ class NumberBox (gtk.Widget):
     def key_press_cb (self, w, e):
         if self.read_only: return
         txt = gtk.gdk.keyval_name(e.keyval)
+        if type(txt) == type(None):
+            # Make sure we don't trigger on unplugging the A/C charger etc
+            return        
         txt = txt.replace('KP_', '')
         if self.get_text() == txt:
             # If there's no change, do nothing
@@ -256,7 +260,8 @@ class NumberBox (gtk.Widget):
     def show_note_editor (self, top=True):
         alloc = self.get_allocation()
         w = gtk.Window()
-        w.set_type_hint(gtk.WINDOW_POPUP)
+        w.set_property('skip-pager-hint', True)
+        w.set_property('skip-taskbar-hint', True)
         w.set_decorated(False)
         w.set_position(gtk.WIN_POS_MOUSE)
         w.set_size_request(alloc.width,alloc.height/2)
@@ -285,7 +290,8 @@ class NumberBox (gtk.Widget):
         #return
         w = gtk.Window()
         w.set_app_paintable(True)
-        w.set_type_hint(gtk.WINDOW_POPUP)
+        w.set_property('skip-pager-hint', True)
+        w.set_property('skip-taskbar-hint', True)
         w.set_decorated(False)
         ns = NumberSelector(upper=self.upper,default=self.get_value())
         def number_changed_cb (b):
@@ -300,7 +306,6 @@ class NumberBox (gtk.Widget):
         r = w.get_allocation()
         my_origin = self.window.get_origin()
         x,y = self.window.get_size()
-        w.show()
         popupx,popupy = w.get_size()
         overlapx = popupx-x
         overlapy = popupy-y
@@ -309,6 +314,7 @@ class NumberBox (gtk.Widget):
         #print 'popup size is',popupx,popupy
         #print 'overlaps are ',overlapx,overlapy
         w.move(my_origin[0]-(overlapx/2),my_origin[1]-(overlapy/2))
+        w.show()
         self.npicker = w
 
     def set_text_interactive (self,text):
@@ -955,11 +961,10 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
         for x in range(self.group_size):
             for y in range(self.group_size):
                 if not self.grid.virgin._get_(x,y):
-                    val = self.grid._get_(x,y)
+                    val = self.__entries__[(x,y)].get_value() # get the value from the user-visible grid, 
                     if val:
                         removed.append((x,y,val,self.trackers_for_point(x,y,val)))
-                        self.remove(x,y)
-                        self.grid.remove(x,y)
+                        self.remove(x,y,do_removal=True)
         return removed
 
     def clear_notes (self, clear_args={'top_text':'','bottom_text':''}):
@@ -1007,16 +1012,20 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
         virgin self and line two represents our game-in-progress.
         """
         self.blank_grid()
-        virgin,in_prog = game.split('\n')
+        if '\n' in game:
+            virgin,in_prog = game.split('\n')
+        else:
+            virgin = game; in_prog = ''
         group_size=int(math.sqrt(len(virgin.split())))
         self.change_grid(virgin,group_size=group_size)
         # This int() will break if we go to 16x16 grids...
-        values = [int(c) for c in in_prog.split()]
-        for row in range(group_size):
-            for col in range(group_size):
-                index = row * 9 + col
-                if values[index] and not self.grid._get_(col,row):
-                    self.add_value(col,row,values[index])
+        if in_prog:
+            values = [int(c) for c in in_prog.split()]
+            for row in range(group_size):
+                for col in range(group_size):
+                    index = row * 9 + col
+                    if values[index] and not self.grid._get_(col,row):
+                        self.add_value(col,row,values[index])
 
     @simple_debug
     def setup_grid (self, grid, group_size):
@@ -1064,21 +1073,23 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
             if self.grid.check_for_completeness():
                 self.emit('puzzle-finished')
         except sudoku.ConflictError, err:
-            conflicts=[self.grid.find_conflict(err.x,err.y,err.value,err.type)]
-            # We check for more than one conflict...  We count on the
-            # order conflicts are checked for in our initial script in
-            # sudoku.py -- ROW then COLUMN then BOX
-            if err.type==sudoku.TYPE_ROW:
-                if err.value in self.grid.cols[err.x]:
-                    conflicts.append(self.grid.find_conflict(err.x,err.y,err.value,sudoku.TYPE_COLUMN))
-            if err.type in [sudoku.TYPE_COLUMN,sudoku.TYPE_ROW]:
-                if err.value in self.grid.boxes[self.grid.box_by_coords[(err.x,err.y)]]:
-                    conflicts.append(self.grid.find_conflict(err.x,err.y,err.value,sudoku.TYPE_BOX))
+            conflicts=self.grid.find_conflicts(err.x,err.y,err.value)
             for conflict in conflicts:
                 widget.set_error_highlight(True)
                 self.__entries__[conflict].set_error_highlight(True)
             self.__error_pairs__[(err.x,err.y)]=conflicts
 
+    def add_value_to_ui (self, x, y, val, trackers=[]):
+        """Add our value back to our grid come hell or high water.
+
+        We add our value -- if there is an error, we make the value
+        appear as if the user had typed it; i.e. it will show up with
+        error highlighting."""
+        try:
+            self.add_value(x, y, val, trackers=[])
+        except sudoku.ConflictError:
+            self.entry_validate(self.__entries__[(x,y)])
+
     @simple_debug
     def add_value (self, x, y, val, trackers=[]):
         """Add value val at position x,y.
@@ -1115,20 +1126,25 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
         If do_removal, remove it from our underlying grid as well.
         """        
         e=self.__entries__[(x,y)]
+        if do_removal and self.grid and self.grid._get_(x,y):
+            self.grid.remove(x,y)
         if self.__error_pairs__.has_key((x,y)):
             e.set_error_highlight(False)
             errors_removed = self.__error_pairs__[(x,y)]
             del self.__error_pairs__[(x,y)]
             for coord in errors_removed:
                 # If we're not an error by some other pairing...
-                if not self.__error_pairs__.has_key((x,y)):
+                if not self.__error_pairs__.has_key(coord):
                     linked_entry = self.__entries__[coord]
                     linked_entry.set_error_highlight(False)
                     # Its possible this highlighted error was never
                     # added to our internal grid, in which case we'd
                     # better make sure it is...
                     if not self.grid._get_(linked_entry.x,linked_entry.y):
-                        self.add_value(linked_entry.x,linked_entry.y,linked_entry.get_value()) 
+                        # entry_validate will add the value to our
+                        # internal grid if there are no other
+                        # conflicts
+                        self.entry_validate(linked_entry)
         # remove trackers
         for t in self.trackers_for_point(x,y):
             remove = []
@@ -1139,8 +1155,6 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
                 self.trackers[t].remove(r)
         if e.get_text(): e.set_value(0)
         e.unset_color()
-        if do_removal and self.grid:
-            self.grid.remove(x,y)
 
     @simple_debug
     def auto_fill (self):
@@ -1161,7 +1175,8 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
     @simple_debug
     def auto_fill_current_entry (self):
         e = self.get_focused_entry()
-        filled = self.grid.auto_fill_for_xy(e.x,e.y)
+        if not e: return
+	filled = self.grid.auto_fill_for_xy(e.x,e.y)
         if filled and filled!=-1:
             self.add_value(filled[0][0],filled[0][1],filled[1])
     
