@@ -40,8 +40,8 @@ typedef struct _GamesCardSelectorClass {
 } GamesCardSelectorClass;
 
 #define GAMES_TYPE_CARD_SELECTOR (games_card_selector_get_type ())
-#define GAMES_CARD_SELECTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_CARD_SELECTOR, GamesCardImages))
-#define GAMES_CARD_SELECTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_CARD_SELECTOR, GamesCardImagesClass))
+#define GAMES_CARD_SELECTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_CARD_SELECTOR, GamesCardSelector))
+#define GAMES_CARD_SELECTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_CARD_SELECTOR, GamesCardSelectorClass))
 #define GAMES_IS_CARD_SELECTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_CARD_SELECTOR))
 #define GAMES_IS_CARD_SELECTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_CARD_SELECTOR))
 #define GAMES_CARD_SELECTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_CARD_SELECTOR))
